adaptive_dialog library

Classes

AdaptiveDialog
Manage common adaptive_dialog settings, etc.
AdaptiveDialogMacOSConfiguration
Manage common macOS settings
AlertDialogAction<T>
Used for specifying showAlertDialog's actions.
DialogTextField
MaterialModalActionSheetConfiguration
SheetAction<T>
Used for specifying showModalActionSheet's actions.

Enums

AdaptiveSelectionMode
Adaptive selection mode
AdaptiveStyle
The visual style of dialogs and sheets.
OkCancelAlertDefaultType
OkCancelResult

Functions

showAlertDialog<T>({required BuildContext context, String? title, String? message, List<AlertDialogAction<T>> actions = const [], bool barrierDismissible = true, AdaptiveStyle? style, bool useActionSheetForCupertino = false, bool useActionSheetForIOS = false, bool useRootNavigator = true, VerticalDirection actionsOverflowDirection = VerticalDirection.up, bool fullyCapitalizedForMaterial = false, bool canPop = true, PopInvokedWithResultCallback<T>? onPopInvokedWithResult, AdaptiveDialogBuilder? builder, Widget? macOSApplicationIcon, RouteSettings? routeSettings, AdaptiveSelectionMode? selectionMode}) → Future<T?>
Show alert dialog, whose appearance is adaptive according to platform
showConfirmationDialog<T>({required BuildContext context, required String title, String? message, String? okLabel, String? cancelLabel, double? contentMaxHeight, List<AlertDialogAction<T>> actions = const [], T? initialSelectedActionKey, bool barrierDismissible = true, AdaptiveStyle? style, bool useRootNavigator = true, bool shrinkWrap = true, bool fullyCapitalizedForMaterial = false, bool canPop = true, PopInvokedWithResultCallback<T>? onPopInvokedWithResult, AdaptiveDialogBuilder? builder, RouteSettings? routeSettings, bool toggleable = true, AdaptiveSelectionMode? selectionMode}) → Future<T?>
Show confirmation dialog, whose appearance is adaptive according to platform
showModalActionSheet<T>({required BuildContext context, String? title, String? message, List<SheetAction<T>> actions = const [], String? cancelLabel, AdaptiveStyle? style, bool isDismissible = true, bool useRootNavigator = true, bool canPop = true, MaterialModalActionSheetConfiguration? materialConfiguration, PopInvokedWithResultCallback<T>? onPopInvokedWithResult, AdaptiveDialogBuilder? builder, RouteSettings? routeSettings, AdaptiveSelectionMode? selectionMode}) → Future<T?>
Show modal action sheet, whose appearance is adaptive according to platform
showOkAlertDialog({required BuildContext context, String? title, String? message, String? okLabel, bool barrierDismissible = true, AdaptiveStyle? alertStyle, AdaptiveStyle? style, bool useActionSheetForCupertino = false, bool useActionSheetForIOS = false, bool useRootNavigator = true, VerticalDirection actionsOverflowDirection = VerticalDirection.up, bool fullyCapitalizedForMaterial = false, bool canPop = true, PopInvokedWithResultCallback<OkCancelResult>? onPopInvokedWithResult, AdaptiveDialogBuilder? builder, RouteSettings? routeSettings, AdaptiveSelectionMode? selectionMode}) → Future<OkCancelResult>
Show OK alert dialog, whose appearance is adaptive according to platform
showOkCancelAlertDialog({required BuildContext context, String? title, String? message, String? okLabel, String? cancelLabel, OkCancelAlertDefaultType? defaultType, bool isDestructiveAction = false, bool barrierDismissible = true, AdaptiveStyle? alertStyle, AdaptiveStyle? style, bool useActionSheetForCupertino = false, bool useActionSheetForIOS = false, bool useRootNavigator = true, VerticalDirection actionsOverflowDirection = VerticalDirection.up, bool fullyCapitalizedForMaterial = false, bool canPop = true, PopInvokedWithResultCallback<OkCancelResult>? onPopInvokedWithResult, AdaptiveDialogBuilder? builder, RouteSettings? routeSettings, AdaptiveSelectionMode? selectionMode}) → Future<OkCancelResult>
Show OK/Cancel alert dialog, whose appearance is adaptive according to platform
showTextAnswerDialog({required BuildContext context, required String keyword, String? title, String? message, String? okLabel, String? cancelLabel, bool isDestructiveAction = false, bool barrierDismissible = true, String? hintText, String? retryTitle, String? retryMessage, String? retryOkLabel, String? retryCancelLabel, AdaptiveStyle? style, bool useRootNavigator = true, VerticalDirection actionsOverflowDirection = VerticalDirection.up, bool fullyCapitalizedForMaterial = false, bool canPop = true, PopInvokedWithResultCallback<List<String>?>? onPopInvokedWithResult, bool autoSubmit = false, bool isCaseSensitive = true, AdaptiveDialogBuilder? builder, AdaptiveSelectionMode? selectionMode}) → Future<bool>
Show text input dialog until answer matches keyword or dialog is cancelled.
showTextInputDialog({required BuildContext context, required List<DialogTextField> textFields, String? title, String? message, String? okLabel, String? cancelLabel, bool isDestructiveAction = false, bool barrierDismissible = true, AdaptiveStyle? style, bool useRootNavigator = true, VerticalDirection actionsOverflowDirection = VerticalDirection.up, bool fullyCapitalizedForMaterial = false, bool canPop = true, PopInvokedWithResultCallback<List<String>?>? onPopInvokedWithResult, bool autoSubmit = false, AdaptiveDialogBuilder? builder, RouteSettings? routeSettings, AdaptiveSelectionMode? selectionMode}) → Future<List<String>?>
Show text input dialog, whose appearance is adaptive according to platform.

Typedefs

AdaptiveDialogBuilder = Widget Function(BuildContext context, Widget child)