AdaptiveStyle enum
The visual style of dialogs and sheets.
Values
- adaptive → const AdaptiveStyle
-
Automatically adapt the dialog style based on the current platform.
- iOS: AdaptiveStyle.iOS (Cupertino)
- macOS: AdaptiveStyle.macOS (using
macos_uion native macOS, or falling back to Cupertino on Web platforms) - Other platforms: AdaptiveStyle.material
- material → const AdaptiveStyle
-
Material Design style dialog.
- cupertino → const AdaptiveStyle
- iOS → const AdaptiveStyle
-
iOS style dialog (Cupertino).
- macOS → const AdaptiveStyle
-
macOS style dialog.
Uses
macos_uiwidgets on native macOS.Note: On Web platforms (both JS and WASM), this falls back to Cupertino (iOS-style) dialogs to maintain full Web and WASM compatibility.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
effectiveStyle(
ThemeData data) → AdaptiveStyle -
isCupertinoStyle(
ThemeData theme) → bool -
isMaterial(
ThemeData theme) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AdaptiveStyle> - A constant List of the values in this enum, in order of their declaration.